<?php
if (!function_exists('saya_social_menu')) {
    /**
     * Add social icons menu
     *
     * @since 1.0.0
     *
     */
    function saya_social_menu()
    {
        if (has_nav_menu('social-menu')) :
            wp_nav_menu(array(
                'theme_location' => 'social-menu',
                'container' => 'ul',
                'menu_class' => 'social-menu'
            ));
        endif;
    }
}


if (!function_exists('saya_custom_body_class')) {
    /**
     * Add sidebar class in body
     *
     * @since 1.0.0
     *
     */
    function saya_custom_body_class($classes)
    {
        global $saya_theme_options;
        if (!empty($saya_theme_options['saya-enable-sticky-sidebar']) &&  $saya_theme_options['saya-enable-sticky-sidebar'] == 1) {
            $classes[] = 'ct-sticky-sidebar';
        }

        if (!empty($saya_theme_options['saya-font-awesome-version-loading'])) {
            $classes[] = 'saya-fontawesome-' . $saya_theme_options['saya-font-awesome-version-loading'];
        }

        return $classes;
    }
}

add_filter('body_class', 'saya_custom_body_class');



if (!function_exists('saya_excerpt_more')) :
    /**
     * Remove ... From Excerpt
     *
     * @since 1.0.0
     */
    function saya_excerpt_more($more)
    {
        if (!is_admin()) {
            return '';
        }
    }
endif;
add_filter('excerpt_more', 'saya_excerpt_more');


if (!function_exists('saya_alter_excerpt')) :
    /**
     * Filter to change excerpt length size
     *
     * @since 1.0.0
     */
    function saya_alter_excerpt($length)
    {
        if (is_admin()) {
            return $length;
        }
        global $saya_theme_options;
        if (!empty($saya_theme_options['saya-excerpt-length'])) {
            return absint($saya_theme_options['saya-excerpt-length']);
        }
        return 25;
    }
endif;
add_filter('excerpt_length', 'saya_alter_excerpt');


if (!function_exists('saya_tag_cloud_widget')) :
    /**
     * Function to modify tag clouds font size
     *
     * @param none
     * @return array $args
     *
     * @since 1.0.0
     *
     */
    function saya_tag_cloud_widget($args)
    {
        $args['largest'] = 0.9; //largest tag
        $args['smallest'] = 0.9; //smallest tag
        $args['unit'] = 'rem'; //tag font unit
        return $args;
    }
endif;
add_filter('widget_tag_cloud_args', 'saya_tag_cloud_widget');


/**
 * Google Fonts
 *
 * @param null
 * @return array
 *
 * @since Saya 1.0.0
 *
 */
if (!function_exists('saya_google_fonts')) :
    function saya_google_fonts()
    {
        $saya_google_fonts = array(
            'Cormorant+Garamond:wght@400;500;600;700' => 'Cormorant Garamond',
            'Karla:wght@400;500;600;700' => 'Karla',
            'Libre+Baskerville:wght@400;700' => 'Libre Baskerville',
            'Merriweather:wght@300;400;700;900' => 'Merriweather',
            'Montserrat:wght@400;700' => 'Montserrat',
            'Mulish:ital,wght@0,300;0,400;1,300' => 'Muli',
            'Open+Sans:ital,wght@0,400;0,600;0,700;1,400' => 'Open Sans',
            'Oswald:wght@300;400;700' => 'Oswald',
            'Oxygen:wght@300;400;700' => 'Oxygen',
            'Playfair+Display:wght@400;500;600;700;800;900' => 'Playfair Display',
            'Poppins:wght@400;500;600;700' => 'Poppins',
            'Roboto:ital,wght@0,300;0,400;0,500;0,700;1,400' => 'Roboto',
            'Voltaire' => 'Voltaire',
            'Yanone+Kaffeesatz:wght@300;400;700' => 'Yanone Kaffeesatz'
        );
        return apply_filters('saya_google_fonts', $saya_google_fonts);
    }
endif;


/**
 * Enqueue the list of fonts.
 */
function saya_customizer_fonts()
{
    wp_enqueue_style('saya_customizer_fonts', 'https://fonts.googleapis.com/css?family=Cormorant+Garamond|Karla|Libre+Baskerville|Merriweather|Montserrat|Muli|Open+Sans|Open+Sans+Condensed|Oswald|Oxygen|Playfair+Display|Poppins|Roboto|Voltaire|Yanone+Kaffeesatz', array(), null);
}

add_action('customize_controls_print_styles', 'saya_customizer_fonts');
add_action('customize_preview_init', 'saya_customizer_fonts');

add_action(
    'customize_controls_print_styles',
    function () {
?>
    <style>
        <?php
        $arr = array('Cormorant Garamond', 'Karla', 'Libre+Baskerville', 'Merriweather', 'Montserrat', 'Muli', 'Open+Sans', 'Open+Sans+Condensed', 'Oswald', 'Oxygen', 'Playfair Display', 'Poppins', 'Roboto', 'Voltaire', 'Yanone+Kaffeesatz');

        foreach ($arr as $font) {
            $font_family = str_replace("+", " ", $font);
            echo '.customize-control select option[value*="' . $font . '"] {font-family: ' . $font_family . '; font-size: 22px;}';
        }
        ?>
    </style>
<?php
    }
);


if (!function_exists('saya_editor_assets')) {
    /**
     * Add styles and fonts for the editor.
     */
    function saya_editor_assets()
    {
        wp_enqueue_style('saya-fonts', saya_fonts_url(), array(), null);

        /* Paragraph Font Options */
        $saya_custom_css = '';
        global $saya_theme_options;
        $saya_theme_options = saya_get_options_value();
        $saya_google_fonts = saya_google_fonts();

        $saya_body_fonts = esc_attr($saya_theme_options['saya-font-family-url']);
        $saya_heading_fonts = esc_attr($saya_theme_options['saya-font-heading-family-url']);

        $saya_google_fonts_enqueue = array(
            $saya_body_fonts,
            $saya_heading_fonts,
        );
        $saya_google_fonts_enqueue_uniques = array_unique($saya_google_fonts_enqueue);
        foreach ($saya_google_fonts_enqueue_uniques as $saya_google_fonts_enqueue_unique) {
            wp_enqueue_style(
                $saya_google_fonts_enqueue_unique,
                '//fonts.googleapis.com/css?family=' . $saya_google_fonts_enqueue_unique . '',
                array(),
                ''
            );
        }
        if (!empty($saya_body_fonts)) {
            $saya_font_family = esc_attr($saya_google_fonts[$saya_body_fonts]);
            if (!empty($saya_font_family)) {
                $saya_custom_css .= ".editor-styles-wrapper .wp-block-table td, .editor-styles-wrapper .wp-block-table th, .editor-styles-wrapper, .editor-styles-wrapper .wp-block-button__link, .editor-styles-wrapper ul li, .editor-styles-wrapper ol li, .editor-styles-wrapper p, .editor-styles-wrapper .editor-block-list__block-edit, .editor-block-list__block  { font-family: '{$saya_font_family}', 'Arial','Helvetica',sans-serif; }";
            }
        }

        /* Heading H1 Font Option */
        if (!empty($saya_heading_fonts)) {
            $saya_heading_font_family = $saya_google_fonts[$saya_heading_fonts];
            if (!empty($saya_heading_font_family)) {
                $saya_custom_css .= ".editor-post-title__block .editor-post-title__input , .editor-styles-wrapper h1, .editor-styles-wrapper h2, .editor-styles-wrapper h3, .editor-styles-wrapper h4, .editor-styles-wrapper h5, .editor-styles-wrapper h6 { font-family: '{$saya_heading_font_family}'; }";
            }
        }

        wp_add_inline_style($saya_google_fonts_enqueue_unique, $saya_custom_css);
    }

    add_action('enqueue_block_editor_assets', 'saya_editor_assets');
}
