<?php

/**
 * Dynamic CSS elements.
 *
 * @package saya
 */
if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}


if (!function_exists('saya_dynamic_css')) :
    /**
     * Dynamic CSS
     *
     * @param null
     * @return null
     *
     * @since 1.0.0
     *
     */
    function saya_dynamic_css()
    {

        global $saya_theme_options;
        $saya_header_color = get_header_textcolor();
        $saya_custom_css = '';

        if (!empty($saya_theme_options['saya-top-header-background-color'])) {
            $top_background = esc_attr($saya_theme_options['saya-top-header-background-color']);
            $saya_custom_css .= "
            .site-header-topbar, .site-header.site-header-v2 .site-header-topbar { background-color: {$top_background}; }
            ";
        }


        if (!empty($saya_header_color)) {
            $saya_custom_css .= ".site-title, .site-title a, h1.site-title a, p.site-title a,  .site-title a:visited { color: #{$saya_header_color}; }";
        }

        if (!empty($saya_theme_options['saya-primary-color'])) {
            $primary_color = esc_attr($saya_theme_options['saya-primary-color']);
            $saya_custom_css .= " :root{ --secondary-color: {$primary_color}; }";
            $saya_custom_css .= " .saya-content-area > .post.sticky > .card, .search-form:hover .search-field, .search-form:active .search-field, .search-form:focus .search-field{border-color: {$primary_color}; }";
            $saya_custom_css .= "input[type='text']:focus, input[type='email']:focus, input[type='password']:focus, input[type='search']:focus, input[type='file']:focus, input[type='number']:focus, input[type='datetime']:focus, input[type='url']:focus, select:focus, textarea:focus, a:focus{ outline-color: {$primary_color}; }";
            $saya_custom_css .= " .site-info a:hover, .site-header.site-header-left-logo .site-header-top .site-header-top-menu li a:hover, .site-header.site-header-left-logo .site-header-top .site-header-top-menu li a:focus, .site-header.site-header-v2 .site-header-topbar .site-header-top-menu li a:hover, .site-header.site-header-v2 .site-header-topbar .site-header-top-menu li a:focus, .top-header-toggle-btn, .category-label-group .cat-links a, .secondary-color, .card_title a:hover, p a:hover, h1 a:hover, h2 a:hover, h3 a:hover, h4 a:hover, h5 a:hover, .author-title a:hover, figure a:hover, table a:hover, span a:hover, strong a:hover, li a:hover, h1 a:hover, a:hover, a:focus, .btn-prmiary-border:hover, .btn-primary-border:focus, .widget li a:hover, .comment-list .comment .comment-body a, .comment-list .comment .comment-body .comment-metadata a.comment-edit-link, .site-header .search-box:hover button i::before, .search-box .close-btn.show i:before, .breadcrumb-trail .trial-items a:hover, .breadcrumbs ul a:hover, .breadcrumb-trail .trial-items .trial-end a, .breadcrumbs ul li:last-child a{ color: {$primary_color}; }";
            $saya_custom_css .= ".site-header-topbar .saya-top-right-menu:hover, .secondary-bg, .btn-secondary, .btn-primary:hover, .btn-primary:focus, .main-navigation ul ul li:hover > a, .search-form:hover .search-submit, .main-navigation #primary-menu ul li.focus > a, .posts-navigation .nav-links a:hover, .category-label-group.bg-label a:hover, .wp-block-button__link:hover, button:hover, input[type='button']:hover, input[type='reset']:hover, input[type='submit']:hover, .pagination .page-numbers, .ct-dark-mode .site-header .sub-menu a:hover, .ajax-pagination .show-more:hover, .widget:not(.saya-menu-social) li a:hover:before, .footer-go-to-top{ background-color: {$primary_color}; }";
        }

        if (!empty($saya_theme_options['saya-header-description-color'])) {
            $site_description_color = esc_attr($saya_theme_options['saya-header-description-color']);
            $saya_custom_css .= ".site-description { color: {$site_description_color}; }";
        }



        if (!empty($saya_theme_options['saya-site-layout-blog-overlay']) && ($saya_theme_options['saya-site-layout-blog-overlay'] == 0)) {

            $saya_custom_css .= "
                    .card-blog-post, .widget-area .widget{
                    box-shadow: none;
                    }
                    ";
        }


        if (!empty($saya_theme_options['saya-enable-underline-link']) && ($saya_theme_options['saya-enable-underline-link'] == 1)) {
            $saya_custom_css .= "
                    .entry-content a{
                   text-decoration: underline;
                    }
                    ";
        } else {
            $saya_custom_css .= "
                    .entry-content a{
                   text-decoration: none;
                    }
                    ";
        }

        /* Paragraph Font Options */
        $saya_google_fonts = saya_google_fonts();
        if (!empty($saya_theme_options['saya-font-family-url'])) {
            $saya_body_fonts = $saya_theme_options['saya-font-family-url'];
            $saya_font_family = esc_attr($saya_google_fonts[$saya_body_fonts]);
            if (!empty($saya_font_family)) {
                $saya_custom_css .= ":root { --primary-font : '{$saya_font_family}'; }";
            }
        }

        /* Heading H1 Font Option */
        if (!empty($saya_theme_options['saya-font-heading-family-url'])) {
            $saya_heading_fonts = esc_attr($saya_theme_options['saya-font-heading-family-url']);
            $saya_heading_font_family = $saya_google_fonts[$saya_heading_fonts];
            if (!empty($saya_heading_font_family)) {
                $saya_custom_css .= ":root { --secondary-font: '{$saya_heading_font_family}'; }";
            }
        }


        if (!empty($saya_theme_options['saya-post-published-updated-date']) && $saya_theme_options['saya-post-published-updated-date'] == 'post-updated') {
            $saya_custom_css .= "
                        .posted-on time.published:not(.updated){
                            display: none;
                        }
                        .posted-on time.updated:not(.published){
                            display: inline-block;
                        }
                    ";
        }

        wp_add_inline_style('saya-style', $saya_custom_css);
    }
endif;
add_action('wp_enqueue_scripts', 'saya_dynamic_css', 99);
