<?php

if (!function_exists('saya_construct_cat_section')) {
    /**
     * Display category section on homepage
     *
     * @since 1.0.0
     *
     */
    function saya_construct_cat_section()
    {
        global $saya_theme_options;
        if ((is_front_page()) && ($saya_theme_options['saya-enable-category-boxes'] == 1)) {
            /**
             * saya_single_cat_posts hook.
             *
             * @since 1.0.0
             *
             * @hooked saya_constuct_single_cat_posts - 10
             */
            do_action('saya_single_cat_posts');
        }
    }
}
add_action('saya_cat_section', 'saya_construct_cat_section', 10);


if (!function_exists('saya_constuct_single_cat_posts')) {
    /**
     * Display latest posts boxes of 3 different categories
     *
     * @since 1.0.0
     *
     */
    function saya_constuct_single_cat_posts()
    {
        global $saya_theme_options;
        $cat1 = absint($saya_theme_options['saya-single-cat-posts-select-1']);
        if (!empty($cat1)) {
?>
            <section class="promo-section sec-spacing">
                <div class="container">
                    <div class="row">
                        <?php
                        $saya_cat_post_args = array(
                            'category__in' => $cat1,
                            'post_type' => 'post',
                            'posts_per_page' => 3,
                            'post_status' => 'publish',
                            'ignore_sticky_posts' => true
                        );
                        $saya_featured_query = new WP_Query($saya_cat_post_args);
                        if ($saya_featured_query->have_posts()) :

                            while ($saya_featured_query->have_posts()) : $saya_featured_query->the_post();
                        ?>
                                <div class="col-1-1 col-sm-1-2 col-md-1-3">
                                    <div class="card card-bg-image card-promo">
                                        <figure class="card_media">
                                            <a href="<?php the_permalink(); ?>">
                                                <?php
                                                if (has_post_thumbnail()) {
                                                    the_post_thumbnail('saya-medium');
                                                } else {
                                                ?>
                                                    <img src="<?php echo esc_url(get_template_directory_uri()) . '/candidthemes/assets/custom/img/saya-medium.jpg' ?>" alt="<?php the_title(); ?>">
                                                <?php
                                                }
                                                ?>
                                            </a>
                                        </figure>

                                        <article class="card_body">
                                            <div class="cat-div">
                                                <?php
                                                    saya_list_category();
                                                ?>
                                            </div>
                                            <h3 class="card_title">
                                                <a href="<?php the_permalink(); ?>">
                                                    <?php the_title(); ?>
                                                </a>
                                            </h3>
                                            
                                        </article>
                                    </div>
                                </div>
                        <?php
                            endwhile;
                        endif;
                        wp_reset_postdata();
                        ?>
                    </div>
                </div>
            </section>
            <?php
        }
    }
}
add_action('saya_single_cat_posts', 'saya_constuct_single_cat_posts', 10);



if (!function_exists('saya_posts_navigation')) {
    /**
     * Display pagination based on type seclected
     *
     * @since 1.0.0
     *
     */
    function saya_posts_navigation()
    {
        global $saya_theme_options;
        if ($saya_theme_options['saya-pagination-options'] == 'numeric') {
            the_posts_pagination();
        } else {
            the_posts_navigation();
        }
    }
}
add_action('saya_action_navigation', 'saya_posts_navigation', 10);


if (!function_exists('saya_related_post')) :
    /**
     * Display related posts from same category
     *
     * @param int $post_id
     * @return void
     *
     * @since 1.0.0
     *
     */
    function saya_related_post($post_id)
    {

        global $saya_theme_options;
        if ($saya_theme_options['saya-single-page-related-posts'] == 0) {
            return;
        }
        $categories = get_the_category($post_id);
        if ($categories) {
            $category_ids = array();
            $category = get_category($category_ids);
            $categories = get_the_category($post_id);
            foreach ($categories as $category) {
                $category_ids[] = $category->term_id;
            }
            $count = $category->category_count;
            if ($count > 1) { ?>
                <div class="related-post">
                    <?php
                    $saya_related_post_title = esc_html($saya_theme_options['saya-single-page-related-posts-title']);
                    if (!empty($saya_related_post_title)) :
                    ?>
                        <h2 class="post-title"><?php echo esc_html($saya_related_post_title); ?></h2>
                    <?php
                    endif;

                    $saya_cat_post_args = array(
                        'category__in' => $category_ids,
                        'post__not_in' => array($post_id),
                        'post_type' => 'post',
                        'posts_per_page' => 2,
                        'post_status' => 'publish',
                        'ignore_sticky_posts' => true
                    );
                    $saya_featured_query = new WP_Query($saya_cat_post_args);
                    ?>
                    <div class="row">
                        <?php
                        if ($saya_featured_query->have_posts()) :

                            while ($saya_featured_query->have_posts()) : $saya_featured_query->the_post();
                        ?>
                                <div class="col-1-1 col-sm-1-2 col-md-1-2">
                                    <div class="card card-blog-post card-full-width">
                                        <?php
                                        if (has_post_thumbnail()) :
                                        ?>
                                            <figure class="card_media">
                                                <a href="<?php the_permalink() ?>">
                                                    <?php the_post_thumbnail('saya-medium'); ?>
                                                </a>
                                            </figure>
                                        <?php
                                        endif;
                                        ?>
                                        <div class="card_body">
                                            <?php saya_list_category(); ?>
                                            <h4 class="card_title">
                                                <a href="<?php the_permalink() ?>">
                                                    <?php the_title(); ?>
                                                </a>
                                            </h4>
                                            <div class="entry-meta">
                                                <?php
                                                saya_posted_on();
                                                saya_posted_by();
                                                ?>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            <?php
                            endwhile;
                            ?>
                    </div>

                <?php
                        endif;
                        wp_reset_postdata();
                ?>
                </div> <!-- .related-post -->
            <?php
            }
        }
    }
endif;
add_action('saya_related_posts', 'saya_related_post', 10, 1);


if (!function_exists('saya_constuct_carousel')) {
    /**
     * Add carousel on header
     *
     * @since 1.0.0
     */
    function saya_constuct_carousel()
    {

        if (is_front_page()) {
            global $saya_theme_options;
            if ($saya_theme_options['saya-enable-slider'] != 1)
                return false;
            $featured_cat = absint($saya_theme_options['saya-select-category']);
            $saya_slider_args = array();
            if (is_rtl()) {
                $saya_slider_args['rtl'] = true;
            }
            $saya_slider_args_encoded = wp_json_encode($saya_slider_args);
            $query_args = array(
                'post_type' => 'post',
                'ignore_sticky_posts' => true,
                'posts_per_page' => 6,
                'cat' => $featured_cat
            );

            $query = new WP_Query($query_args);
            if ($query->have_posts()) :
            ?>
                <section class="hero hero-slider-section">
                    <div class="container">
                        <!-- slick slider component start -->
                        <div class="hero_slick-slider" data-slick='<?php echo $saya_slider_args_encoded; ?>'>
                            <?php
                            $i = 1;
                            while ($query->have_posts()) :
                                $query->the_post();
                                if (has_post_thumbnail()) {
                                    $wrapper_class = 'card card-bg-image';
                                } else {
                                    $wrapper_class = 'card card-bg-image card-no-thumbnail';
                                }

                            ?>
                                <div class="<?php echo $wrapper_class; ?>">
                                    <article class="card_body">
                                        <?php
                                        saya_list_category();
                                        ?>

                                        <h3 class="card_title">
                                            <a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                                        </h3>

                                        <div class="entry-meta">
                                            <?php
                                            saya_posted_on();
                                            saya_posted_by();
                                            ?>
                                        </div>
                                    </article>
                                    <?php
                                    if (has_post_thumbnail()) {
                                    ?>
                                        <div class="post-thumb">
                                            <figure class="card_media">
                                                <a href="<?php the_permalink(); ?>">
                                                    <?php
                                                    $cropped_image = $saya_theme_options['saya-image-size-slider'];
                                                    if ($cropped_image == 'cropped-image') {
                                                        the_post_thumbnail('saya-large');
                                                    } else {
                                                        the_post_thumbnail();
                                                    }
                                                    ?>
                                                </a>
                                            </figure>
                                        </div>
                                    <?php
                                    }
                                    ?>
                                    
                                </div>
                            <?php
                                $i++;

                            endwhile;
                            ?>
                        </div>
                    </div>
                </section><!-- .hero -->
            <?php
            endif;
            wp_reset_postdata();
        } //is_front_page
    }
}
add_action('saya_carousel', 'saya_constuct_carousel', 10);


if (!function_exists('saya_breadcrumb_options')) :
    /**
     * Functions to manage breadcrumbs
     */
    function saya_breadcrumb_options()
    {
        global $saya_theme_options;
        if (($saya_theme_options['saya-blog-site-breadcrumb'] == 1) && !is_front_page()) {
            $breadcrumb_from = $saya_theme_options['saya-breadcrumb-display-from-option'];

            if ((function_exists('yoast_breadcrumb')) && ($breadcrumb_from == 'yoast-breadcrumb')) {
            ?>
                <div class="saya-breadcrumb-wrapper">
                    <?php
                    yoast_breadcrumb();
                    ?>
                </div>
            <?php
            } elseif ((function_exists('rank_math_the_breadcrumbs')) && ($breadcrumb_from == 'rankmath-breadcrumb')) {
            ?>
                <div class="saya-breadcrumb-wrapper">
                    <?php
                    rank_math_the_breadcrumbs();
                    ?>
                </div>
            <?php
            } elseif ((function_exists('bcn_display')) && ($breadcrumb_from == 'breadcrumb-navxt')) {
            ?>
                <div class="saya-breadcrumb-wrapper">
                    <?php
                    bcn_display();
                    ?>
                </div>
            <?php
            } else {
            ?>
                <div class="saya-breadcrumb-wrapper">
                    <div class="container">
                        <?php
                        saya_breadcrumbs();
                        ?>
                    </div>
                </div>
                <!-- .saya-breadcrumb -->
<?php
            }
        }
    }
endif;
add_action('saya_breadcrumb', 'saya_breadcrumb_options', 10);


/**
 * BreadCrumb Settings
 */
if (!function_exists('saya_breadcrumbs')) :
    function saya_breadcrumbs()
    {
        $breadcrumb_args = array(
            'container' => 'div',
            'show_browse' => false
        );
        global $saya_theme_options;

        $saya_you_are_here_text = esc_html($saya_theme_options['saya-breadcrumb-text']);


        if (!empty($saya_you_are_here_text)) {
            $saya_you_are_here_text = "<span class='breadcrumb'>" . $saya_you_are_here_text . "</span>";
        }
        echo "<div class='breadcrumbs init-animate clearfix'>" . $saya_you_are_here_text . "<div id='saya-breadcrumbs' class='clearfix'>";
        breadcrumb_trail($breadcrumb_args);
        echo "</div></div>";
    }
endif;
