<?php
if (!function_exists('saya_do_skip_to_content_link')) {
    /**
     * Add skip to content link before the header.
     *
     * @since 1.0.0
     */
    function saya_do_skip_to_content_link()
    {
?>
        <a class="skip-link screen-reader-text" href="#content"><?php esc_html_e('Skip to content', 'saya'); ?></a>
    <?php
    }
}
add_action('saya_before_header', 'saya_do_skip_to_content_link', 10);



if (!function_exists('saya_construct_header')) {
    /**
     * Add header
     *
     * @since 1.0.0
     */
    function saya_construct_header()
    {
        global $saya_theme_options;
        $saya_enable_top_header = absint($saya_theme_options['saya-enable-top-header']);
        $saya_enable_top_menu = absint($saya_theme_options['saya-enable-top-header-menu']);
    ?>
        <header id="masthead" class="site-header site-header-v2">
            <?php
            if (($saya_enable_top_header == 1)) {
            ?>
                <section class="site-header-topbar">
                    <a href="#" class="top-header-toggle-btn">
                        <i class="fa fa-chevron-down" aria-hidden="true"></i>
                    </a>
                    <div class="container">
                        <div class="row">

                            <div class="col col-sm-2-3 col-md-2-3 col-lg-2-4">
                                <?php
                                /**
                                 * saya_top_left hook.
                                 *
                                 * @since 1.0.0
                                 *
                                 * @hooked saya_top_menu - 10
                                 *
                                 */
                                do_action('saya_top_left');
                                ?>
                            </div>

                            <div class="col col-sm-1-3 col-md-1-3 col-lg-1-4">

                                <div class="saya-menu-social topbar-flex-grid">
                                    <?php
                                    /**
                                     * saya_menu_right hook.
                                     *
                                     * @since 1.0.0
                                     *
                                     * @hooked saya_menu_social - 10
                                     * @hooked saya_menu_search - 20
                                     *
                                     */
                                    do_action('saya_menu_right');
                                    ?>
                                </div>

                            </div>

                        </div>
                    </div>
                </section>
            <?php
            }

            /**
             * saya_main_header hook.
             *
             * @since 1.0.0
             *
             * @hooked saya_construct_main_header - 10
             */
            do_action('saya_main_header');
            ?>
        </header><!-- #masthead -->
    <?php

    }
}
add_action('saya_header', 'saya_construct_header', 10);

if (!function_exists('saya_top_menu')) {
    /**
     * Add menu on top header.
     *
     * @since 1.0.0
     */
    function saya_top_menu()
    {
        global $saya_theme_options;

        if ($saya_theme_options['saya-enable-top-header-menu'] != 1)
            return false;
    ?>
        <nav class="site-header-top-nav">
            <?php
            wp_nav_menu(array(
                'theme_location' => 'top-menu',
                'container' => 'ul',
                'menu_class' => 'site-header-top-menu',
                'depth' => 1
            ));
            ?>
        </nav>
        <?php
    }
}
add_action('saya_top_left', 'saya_top_menu', 10);


if (!function_exists('saya_construct_main_header')) {
    /**
     * Add Main Header
     *
     * @since 1.0.0
     */
    function saya_construct_main_header()
    {

        /**
         * saya_header_default hook.
         *
         * @since 1.0.0
         *
         * @hooked saya_default_header - 10
         */
        do_action('saya_header_default');
    }
}
add_action('saya_main_header', 'saya_construct_main_header', 10);


if (!function_exists('saya_default_header')) {
    /**
     * Add Default header
     *
     * @since 1.0.0
     */
    function saya_default_header()
    {

        //has header image
        $has_header_image = has_header_image();
        global $saya_theme_options;
        $center_class = esc_attr($saya_theme_options['saya-make-logo-center']);
        $logo_class = (1 == $center_class) ? 'logo-center' : ''; // $r is set to 'Yes'

        ?>
        <div id="site-nav-wrap">
            <section id="site-navigation" class="site-header-top header-main-bar <?php echo esc_attr($logo_class); ?>" <?php if (!empty($has_header_image)) { ?> style="background-image: url(<?php echo header_image(); ?>);" <?php } ?>>
                <div class="container">
                    <div class="row">
                        <div class="col-md-1-2 branding-box">
                            <?php
                            /**
                             * saya_branding hook.
                             *
                             * @since 1.0.0
                             *
                             * @hooked saya_construct_branding - 10
                             */
                            do_action('saya_branding');
                            ?>
                        </div>

                        <div class="col-md-1-2 site-header-ad-wrapper">
                            <?php
                            /**
                             * saya_advertisement hook.
                             *
                             * @since 1.0.0
                             *
                             * @hooked saya_construct_advertisement - 10
                             */
                            do_action('saya_advertisement');
                            ?>

                        </div>
                    </div>
                </div>
            </section>

            <section class="site-header-bottom">
                <div class="container">
                    <?php
                    /**
                     * saya_main_menu hook.
                     *
                     * @since 1.0.0
                     *
                     * @hooked saya_construct_main_menu - 10
                     */
                    do_action('saya_main_menu');
                    ?>

                </div>
            </section>
        </div>
    <?php
    }
}
add_action('saya_header_default', 'saya_default_header', 10);





if (!function_exists('saya_construct_branding')) {
    /**
     * Add Branding on Header
     *
     * @since 1.0.0
     */
    function saya_construct_branding()
    {
    ?>
        <div class="site-branding">
            <?php
            the_custom_logo();
            if (is_front_page() && is_home()) :
            ?>
                <h1 class="site-title"><a href="<?php echo esc_url(home_url('/')); ?>" rel="home"><?php bloginfo('name'); ?></a></h1>
            <?php
            else :
            ?>
                <p class="site-title"><a href="<?php echo esc_url(home_url('/')); ?>" rel="home"><?php bloginfo('name'); ?></a></p>
            <?php
            endif;
            $saya_description = get_bloginfo('description', 'display');
            if ($saya_description || is_customize_preview()) :
            ?>
                <p class="site-description"><?php echo $saya_description; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
                                            ?></p>
            <?php endif; ?>
        </div><!-- .site-branding -->

        <button id="menu-toggle-button" class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
            <span class="line"></span>
            <span class="line"></span>
            <span class="line"></span>
        </button>
        <?php
    }
}
add_action('saya_branding', 'saya_construct_branding', 10);




if (!function_exists('saya_construct_advertisement')) {
    /**
     * Add Advertisement on Header
     *
     * @since 1.0.0
     */
    function saya_construct_advertisement()
    {
        global $saya_theme_options;
        if ($saya_theme_options['saya-enable-headr-advertisement'] != 1)
            return false;

        $saya_advertisement_image = $saya_theme_options['saya-header-ads-image-file'];
        $saya_advertisement_url = $saya_theme_options['saya-header-ads-image-url'];
        if (!empty($saya_advertisement_image) && !empty($saya_advertisement_url)) {
        ?>
            <a href="<?php echo esc_url($saya_advertisement_url); ?>" target="_blank">
                <img src="<?php echo esc_url($saya_advertisement_image); ?>">
            </a>
        <?php
        } elseif (!empty($saya_advertisement_image)) {
        ?>
            <img src="<?php echo esc_url($saya_advertisement_image); ?>">
        <?php
        }
    }
}
add_action('saya_advertisement', 'saya_construct_advertisement', 10);



if (!function_exists('saya_construct_main_menu')) {
    /**
     * Add Main Menu on Header
     *
     * @since 1.0.0
     */
    function saya_construct_main_menu()
    {
        ?>
        <nav class="main-navigation">
            <ul id="primary-menu" class="nav navbar-nav nav-menu">
                <?php
                if (has_nav_menu('menu-1')) :
                    wp_nav_menu(array(
                        'theme_location' => 'menu-1',
                        'items_wrap' => '%3$s',
                        'container' => false
                    ));
                else :
                    wp_list_pages(array('depth' => 0, 'title_li' => ''));
                endif; // has_nav_menu
                ?>
                <button class="close_nav"><i class="fa fa-times"></i></button>
            </ul>
        </nav><!-- #site-navigation -->

        
    <?php
    }
}
add_action('saya_main_menu', 'saya_construct_main_menu', 10);



if (!function_exists('saya_menu_social')) {
    /**
     * Add social icon menu on menu .
     *
     * @since 1.0.0
     */
    function saya_menu_social()
    {
        global $saya_theme_options;
        if ($saya_theme_options['saya-enable-top-header-social'] != 1)
            return false;
        saya_social_menu();
    }
}
add_action('saya_menu_right', 'saya_menu_social', 10);


if (!function_exists('saya_menu_search')) {
    /**
     * Add search icon on menu.
     *
     * @since 1.0.0
     */
    function saya_menu_search()
    {
        global $saya_theme_options;
        if ($saya_theme_options['saya-enable-top-header-search'] != 1)
            return false;
    ?>
        <div class="search-box">
            <button class="search-toggle"><i class="fa fa-search"></i></button>
            <button class="close-btn"><i class="fa fa-times"></i></button>
            <div class="search-section">
                <?php get_search_form(); ?>
            </div>
        </div>
<?php
    }
}
add_action('saya_menu_right', 'saya_menu_search', 20);
